@@ -199,6 +199,65 @@ class AlarmChangelog(object):
           self.id, self.alarm_id, self.state)).encode('utf-8')
 
 
+class LatestAlarmState(object):
+    def __init__(self, entity_id, check_id, alarm_id, timestamp, state):
+        self.entity_id = entity_id
+        self.check_id = check_id
+        self.alarm_id = alarm_id
+        self.timestamp = timestamp
+        self.state = state
+
+    def __str__(self):
+        return self.__repr__()
+
+    def __repr__(self):
+        return ('<LatestAlarmState: entity_id=%s, check_id=%s, alarm_id=%s, '
+                'state=%s ...>' %
+                (self.entity_id, self.check_id, self.alarm_id, self.state)) \
+                .encode('utf-8')
+
+
+class AgentToken(object):
+    def __init__(self, id, label, token):
+        self.id = id
+        self.label = label
+        self.token = token
+
+    def __str__(self):
+        return self.__repr__()
+
+    def __repr__(self):
+        return ('<AgentToken: id=%s, label=%s, token=%s>' %
+                (self.id, self.label, self.token)).encode('utf-8')
+
+class Agent(object):
+    def __init__(self, id, last_connected):
+        self.id = id
+        self.last_connected = last_connected
+
+    def __str__(self):
+        return self.__repr__()
+
+    def __repr__(self):
+        return ('<Agent: id=%s, last_connected=%s>' % 
+            (self.id, self.last_connected)).encode('utf-8')
+
+class AgentConnection(object):
+    def __init__(self, id, endpoint, agent_id, bundle_version, process_version, agent_ip):
+        self.id = id
+        self.endpoint = endpoint
+        self.agent_id = agent_id
+        self.bundle_version = bundle_version
+        self.process_version = process_version
+        self.agent_ip = agent_ip
+
+    def __str__(self):
+        return self.__repr__()
+
+    def __repr__(self):
+        return ('<AgentConnection: id=%s, agent_id=%s>' % 
+            (self.id, self.agent_id)).encode('utf-8')
+
 class MonitoringDriver(object):
     """
     A base MonitoringDriver to derive from.
