@@ -32,7 +32,9 @@ from rackspace_monitoring.utils import value_to_bool
 from rackspace_monitoring.base import (MonitoringDriver, Entity,
                                       NotificationPlan, MonitoringZone,
                                       Notification, CheckType, Alarm, Check,
-                                      NotificationType, AlarmChangelog)
+                                      NotificationType, AlarmChangelog,
+                                      LatestAlarmState, Agent, AgentToken,
+                                      AgentConnection)
 
 from libcloud.common.rackspace import AUTH_URL_US
 from libcloud.common.openstack import OpenStackBaseConnection
@@ -59,39 +61,6 @@ class RackspaceMonitoringValidationError(LibcloudError):
         return string.encode('utf-8')
 
 
-class LatestAlarmState(object):
-    def __init__(self, entity_id, check_id, alarm_id, timestamp, state):
-        self.entity_id = entity_id
-        self.check_id = check_id
-        self.alarm_id = alarm_id
-        self.timestamp = timestamp
-        self.state = state
-
-    def __str__(self):
-        return self.__repr__()
-
-    def __repr__(self):
-        return ('<LatestAlarmState: entity_id=%s, check_id=%s, alarm_id=%s, '
-                'state=%s ...>' %
-                (self.entity_id, self.check_id, self.alarm_id, self.state)) \
-                .encode('utf-8')
-
-
-class AgentToken(object):
-    def __init__(self, id, label, token):
-        self.id = id
-        self.label = label
-        self.token = token
-
-    def __str__(self):
-        return self.__repr__()
-
-    def __repr__(self):
-        return ('<AgentToken: id=%s, label=%s, token=%s>' %
-                (self.id, self.label, self.token)).encode('utf-8')
-
-
-
 class RackspaceMonitoringResponse(Response):
 
     valid_response_codes = [httplib.CONFLICT]
@@ -256,6 +225,7 @@ class RackspaceMonitoringDriver(MonitoringDriver):
     def _plural_to_singular(self, name):
         kv = {'entities': 'entity',
               'agent_tokens': 'agent_token',
+              'agents': 'agent',
               'alarms': 'alarm',
               'checks': 'check',
               'notifications': 'notification',
@@ -665,23 +635,9 @@ class RackspaceMonitoringDriver(MonitoringDriver):
         return Entity(id=entity['id'], label=entity['label'],
                       extra=entity['metadata'], driver=self, ip_addresses=ips)
 
-    def delete_entity(self, entity, ex_delete_children=False, **kwargs):
-        try:
-            return self._delete(url="/entities/%s" % (entity.id),
-                                kwargs=kwargs)
-        except RackspaceMonitoringValidationError:
-            e = sys.exc_info()[1]
-            type = e.details['type']
-            if not ex_delete_children or e.type != 'childrenExistError':
-                raise e
-
-            if type == 'Check':
-                self.ex_delete_checks(entity=entity)
-            elif type == 'Alarm':
-                self.ex_delete_alarms(entity=entity)
-
-            return self.delete_entity(entity=entity, ex_delete_children=True,
-                                      **kwargs)
+    def delete_entity(self, entity, **kwargs):
+        return self._delete(url="/entities/%s" % (entity.id),
+                            kwargs=kwargs)
 
     def list_entities(self, ex_next_marker=None):
         value_dict = {'url': '/entities',
@@ -718,6 +674,11 @@ class RackspaceMonitoringDriver(MonitoringDriver):
 
         return LazyList(get_more=self._get_more, value_dict=value_dict)
 
+    def get_entity_host_info(self, entity_id, info_type):
+        url = "/entities/%s/agent/host_info/%s" % (entity_id, info_type)
+        resp = self.connection.request(url)
+        return resp.object
+
     # Agent tokens
 
     def list_agent_tokens(self):
@@ -747,6 +708,33 @@ class RackspaceMonitoringDriver(MonitoringDriver):
         return AgentToken(id=agent_token['id'], label=agent_token['label'],
                           token=agent_token['token'])
 
+    # Agent
+
+    def _to_agents(self, agent, value_dict):
+        return Agent(id=agent['id'], last_connected=agent['last_connected'])
+
+    def _to_agent_connection(self, conn, value_dict):
+        return AgentConnection(id=conn['id'], endpoint=conn['endpoint'],
+            agent_id=conn['agent_id'], bundle_version=conn['bundle_version'],
+            process_version=conn['process_version'], agent_ip=conn['agent_ip'])
+
+    def list_agents(self):
+        value_dict = {'url': '/agents',
+                      'list_item_mapper': self._to_agents}
+
+        return LazyList(get_more=self._get_more, value_dict=value_dict)
+
+    def list_agent_connections(self, agent_id):
+        value_dict = {'url': "/agents/%s/connections" % (agent_id),
+                      'list_item_mapper': self._to_agent_connection}
+
+        return LazyList(get_more=self._get_more, value_dict=value_dict)
+
+    def get_agent_host_info(self, agent_id, info_type):
+        url = "/agents/%s/host_info/%s" % (agent_id, info_type)
+        resp = self.connection.request(url)
+        return resp.object
+
     #########
     ## Other
     #########
